<?php

/* Helper functions and classes with static methods for usage in theme */

/*replace more excerpt text*/
function love_pet_replace_excerpt( $more ) {
	return '...';
}
add_filter( 'excerpt_more', 'love_pet_replace_excerpt' );

if ( ! function_exists('love_pet_the_attached_image') ) : /**
 * Print the attached image with a link to the next attached image.
 */ {
	function love_pet_the_attached_image() {
		$post = get_post();
		/**
		 * Filter the default attachment size.
		 *
		 * @param array $dimensions {
		 *     An array of height and width dimensions.
		 *
		 * @type int $height Height of the image in pixels. Default 810.
		 * @type int $width Width of the image in pixels. Default 810.
		 * }
		 */
		$attachment_size     = apply_filters( 'love_pet_attachment_size', array( 810, 810 ) );
		$next_attachment_url = wp_get_attachment_url();

		/*
		 * Grab the IDs of all the image attachments in a gallery so we can get the URL
		 * of the next adjacent image in a gallery, or the first image (if we're
		 * looking at the last image in a gallery), or, in a gallery of one, just the
		 * link to that image file.
		 */
		$attachment_ids = get_posts( array(
			'post_parent'    => $post->post_parent,
			'fields'         => 'ids',
			'numberposts'    => - 1,
			'post_status'    => 'inherit',
			'post_type'      => 'attachment',
			'post_mime_type' => 'image',
			'order'          => 'ASC',
			'orderby'        => 'menu_order ID',
		) );

		// If there is more than 1 attachment in a gallery...
		if ( count( $attachment_ids ) > 1 ) {
			foreach ( $attachment_ids as $attachment_id ) {
				if ( $attachment_id == $post->ID ) {
					$next_id = current( $attachment_ids );
					break;
				}
			}

			// get the URL of the next image attachment...
			if ( $next_id ) {
				$next_attachment_url = get_attachment_link( $next_id );
			} // or get the URL of the first image attachment.
			else {
				$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
			}
		}

		printf( '<a href="%1$s" rel="attachment">%2$s</a>',
			esc_url( $next_attachment_url ),
			wp_get_attachment_image( $post->ID, $attachment_size )
		);
	}
}
endif;

/* Custom template tags */
{
	/*support structured data - SEO optimize*/
	if(!function_exists('love_pet_structured_data')):
		function love_pet_structured_data(){ ?>
			<div class="screen-reader-text">
				<?php /*publisher*/ ?>
				<div itemprop="publisher" itemscope="itemscope" itemtype="https://schema.org/Organization">
					<div itemprop="logo" itemscope="itemscope" itemtype="https://schema.org/ImageObject">
						<meta itemprop="url" content="<?php echo esc_url(home_url('/')); ?>" />
						<meta itemprop="width" content="100" />
						<meta itemprop="height" content="100" />
					</div>
					<meta itemprop="name" content="<?php the_author(); ?>" />
				</div>
				<?php /*date modified*/ ?>
				<span itemprop="dateModified">
					<time datetime="<?php echo esc_attr( get_the_modified_time( 'Y-m-d' ) ); ?>">
						<?php the_modified_date(); ?>
					</time>
				</span>
				<?php /*date published*/ ?>
				<span itemprop="datePublished" content="<?php echo get_the_time('c'); ?>"><?php echo get_the_time('c'); ?></span>
				<?php /*post categories*/ ?>
				<div itemprop="articleSection"><?php echo love_pet_blog_categories(); ?></div>
			</div>
		<?php }
	endif;

	/*404 search form*/
	if(!function_exists('love_pet_custom_search_form')):
		function love_pet_custom_search_form(){ ?>
			<form action="<?php echo esc_url(home_url('/')); ?>" class="error-search-form" method="get">
				<input type="text" placeholder="<?php esc_attr_e('Enter your text', 'love-pet'); ?>" name="s" required>
				<input type="submit" value="<?php esc_attr_e('Search', 'love-pet'); ?>">
			</form>
		<?php }
	endif;
	
	/* Filter function to be used with number_format_i18n filter hook */
    if( ! function_exists( 'love_pet_paging_zero_prefix' ) ) :
		function love_pet_paging_zero_prefix( $format ) {
			$number = intval( $format );
			if( intval( $number / 10 ) > 0 ) {
				return $format;
			}
			return '0' . $format;
		}
    endif;
	/*blog pagination*/
	if ( ! function_exists( 'love_pet_paging_nav' ) ) :
		function love_pet_paging_nav( $wp_query = null ) {

			if ( ! $wp_query ) {
				$wp_query = $GLOBALS['wp_query'];
			}

			/*Don't print empty markup if there's only one page.*/

			if ( $wp_query->max_num_pages < 2 ) {
				return;
			}

			$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
			$pagenum_link = html_entity_decode( get_pagenum_link() );
			$query_args   = array();
			$url_parts    = explode( '?', $pagenum_link );

			if ( isset( $url_parts[1] ) ) {
				wp_parse_str( $url_parts[1], $query_args );
			}

			add_filter( 'number_format_i18n', 'love_pet_paging_zero_prefix' );

			$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
			$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

			$format = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link,
				'index.php' ) ? 'index.php/' : '';
			$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%',
				'paged' ) : '?paged=%#%';

			/*Set up paginated links.*/
			$links = paginate_links( array(
				'base'      => $pagenum_link,
				'format'    => $format,
				'total'     => $wp_query->max_num_pages,
				'current'   => $paged,
				'mid_size'  => 1,
				'add_args'  => array_map( 'urlencode', $query_args ),
				'prev_text' => '',
				'next_text' => '',
				'type' 		=> 'list'
			) );

			remove_filter( 'number_format_i18n', 'love_pet_paging_zero_prefix' );

			if ( $links ) :

				?>
				<nav class="paging-navigation">
					<h1 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'love-pet'); ?></h1>
						<?php echo wp_kses($links,
						array(
							'ul' => array(
								'class' => array(),
							),
							'li' => array(),
							'span' => array(
								'class' => array(),
							),
							'a' => array(
								'class' => array(),
								'href' => array(),
							),
						)); ?>
				</nav>
			<?php
			endif;
		}
	endif;
	/*post date*/
	if ( ! function_exists( 'love_pet_post_date' ) ) :
		function love_pet_post_date() {
			$post_date = get_the_date('d');
			$post_m = get_the_date('F');
			$post_y = get_the_date('Y');
			$post_info = '';
			$post_info .= '<span class="date-month">'.$post_m.'</span>';
			$post_info .= '<span class="date-day">'.$post_date.',</span>';
			$post_info .= '<span class="date-year">'.$post_y.'</span>';

			return $post_info;
		}
	endif;
	/*blog categories*/
	if(!function_exists('love_pet_blog_categories')):
		function love_pet_blog_categories(){
			$categories_string = '';
			$categories = get_the_category();
			$separator = ', ';
			$output = '';
			if ( ! empty( $categories ) ) {
				foreach( $categories as $category ) {
					$output .= '<a href="' . esc_url( get_category_link( $category->term_id ) ) . '" title="' . esc_attr( sprintf( esc_html__( 'View all posts in %s', 'love-pet'), $category->name ) ) . '">' . esc_html( $category->name ) . '</a>' . $separator;
				}
				$categories_string .= trim( $output, $separator );
			}
			return $categories_string;
		}
	endif;
	/*custom excerpt*/
	if( ! function_exists('love_pet_excerpt')):
		function love_pet_excerpt($limit) {
			$excerpt = explode(' ', get_the_excerpt(), $limit);
			if (count($excerpt)>=$limit) {
				array_pop($excerpt);
				$excerpt = implode(" ",$excerpt).'...';
			} else {
				$excerpt = implode(" ",$excerpt);
			} 
			$excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
			return $excerpt;
		}
	endif;

	/*post navigation*/
	if ( ! function_exists('love_pet_theme_post_nav') ) :
		function love_pet_theme_post_nav() {

			$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
			$next     = get_adjacent_post( false, '', false );

			if ( ! $next && ! $previous ) {
				return;
			}

			?>

			<div class="blog-post-nav flw">
				<?php if(!empty($previous)){/*prev post*/
					$prev_link = get_permalink($previous);
					$prev_post_id = $previous->ID;
					$prev_post_thumb = wp_get_attachment_image_src( get_post_thumbnail_id($prev_post_id), 'thumbnail' ); ?>
					<div class="prev-post post-nav-control">
						<div class="post-nav-sum">
							<?php previous_post_link('%link'); ?>
							<a class="post-nav-link" href="<?php echo esc_url($prev_link); ?>"><span class="ion-android-arrow-dropleft-circle"></span> <?php esc_html_e('Previous', 'love-pet'); ?></a>
						</div>
						<?php if(!empty($prev_post_thumb)): ?>
							<a class="post-nav-thumb" href="<?php echo esc_url($prev_link); ?>">
								<img src="<?php echo esc_url($prev_post_thumb[0]); ?>">
							</a>
						<?php endif; ?>
					</div>
				<?php } ?>

				<?php if(!empty($next)){/*next post*/
					$next_link = get_permalink($next);
					$next_post_id = $next->ID;
					$next_post_thumb = wp_get_attachment_image_src( get_post_thumbnail_id($next_post_id), 'thumbnail' ); ?>
					<div class="next-post post-nav-control">
						<div class="post-nav-sum">
							<?php next_post_link('%link'); ?>
							<a class="post-nav-link" href="<?php echo esc_url($next_link); ?>"><?php esc_html_e('Next', 'love-pet'); ?> <span class="ion-android-arrow-dropright-circle"></span></a>
						</div>
						<?php if(!empty($next_post_thumb)): ?>
							<a class="post-nav-thumb" href="<?php echo esc_url($next_link); ?>">
								<img src="<?php echo esc_url($next_post_thumb[0]); ?>">
							</a>
						<?php endif; ?>
					</div>
				<?php } ?>
			</div>
			<?php
		}
	endif;
	/**
	 * Find out if blog has more than one category.
	 * @return boolean true if blog has more than 1 category
	 */
	function love_pet_categorized_blog() {
		if ( false === ( $all_the_cool_cats = get_transient( 'love_pet_category_count' ) ) ) {
			// Create an array of all the categories that are attached to posts
			$all_the_cool_cats = get_categories( array(
				'hide_empty' => 1,
			) );

			// Count the number of categories that are attached to the posts
			$all_the_cool_cats = count( $all_the_cool_cats );

			set_transient( 'love_pet_category_count', $all_the_cool_cats );
		}

		if ( 1 !== (int) $all_the_cool_cats ) {
			// This blog has more than 1 category so love_pet_categorized_blog should return true
			return true;
		} else {
			// This blog has only 1 category so love_pet_categorized_blog should return false
			return false;
		}
	}

}

/*theme suopprt*/
function love_pet_theme_support() {
	add_theme_support( 'post-thumbnails' );
    add_theme_support( 'woocommerce' );
    add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
	/*load all font-weight typography*/
	if ( class_exists( 'Kirki_Fonts_Google' ) ) {
        Kirki_Fonts_Google::$force_load_all_variants = true;
    }
}
add_action( 'after_setup_theme', 'love_pet_theme_support' );


/*call shopping cart*/
function love_pet_shopping_cart(){
    if(class_exists('Woocommerce')):
	global $woocommerce;
	$total_item = $woocommerce->cart->cart_contents_count;
	$total_price = $woocommerce->cart->get_cart_total(); ?>
		<div class="theme-shopping-cart">
			<a class="fa fa-shopping-bag shopping-cart-icon" href="<?php echo wc_get_cart_url(); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'love-pet' ); ?>">
				<span class="counter-cart"><?php echo esc_html($total_item); ?></span>
			</a>
			<strong class="cart-price-total">
				<span class="cart-price-txt"><?php esc_html_e('Cart', 'love-pet'); ?></span>
				<?php echo wp_kses_post($total_price); ?>
			</strong>
			<div class="theme-minicart">
				<?php woocommerce_mini_cart(); ?>
			</div>
		</div>
	<?php endif;
}

/*shopping cart - total item*/
function love_pet_cart_total_item( $fragments ) {
	global $woocommerce;
	$total_item = $woocommerce->cart->cart_contents_count;
	ob_start(); ?>
	<span class="counter-cart"><?php echo esc_html($total_item); ?></span>
	<?php $fragments['span.counter-cart'] = ob_get_clean();	
	return $fragments;
}
add_filter('add_to_cart_fragments', 'love_pet_cart_total_item');


/*shopping cart - total price*/
function love_pet_cart_total_price( $fragments ) {
	global $woocommerce;
	$total_price = $woocommerce->cart->get_cart_total();
	ob_start(); ?>
	<strong class="cart-price-total">
		<span class="cart-price-txt"><?php esc_html_e('Cart', 'love-pet'); ?></span>
		<?php echo wp_kses_post($total_price); ?>
	</strong>
	<?php $fragments['strong.cart-price-total'] = ob_get_clean();	
	return $fragments;
}
add_filter('add_to_cart_fragments', 'love_pet_cart_total_price');

/*shopping cart - list item*/
function love_pet_cart_list($fragments) {
	global $woocommerce;
	$total_item = $woocommerce->cart->cart_contents_count;
    ob_start(); ?>
		<div class="theme-minicart">
			<?php woocommerce_mini_cart(); ?>
		</div>
	<?php
	$fragments['div.theme-minicart'] = ob_get_clean();
    return $fragments;
}
add_filter( 'add_to_cart_fragments', 'love_pet_cart_list');


/*Custom comment output*/
function love_pet_comment_list($comment, $args, $depth){
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
		<div class="comment-post-pingback">
			<?php esc_html_e( 'Pingback:', 'love-pet' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'love-pet' ), '<span class="edit-link">', '</span>' ); ?>
		</div>
	<?php
		break;
		default :
	?>
	<div id="comment-<?php comment_ID(); ?>" class="comment-item" itemscope itemtype="http://schema.org/Comment">
		<div class="comment-avatar">
			<?php echo get_avatar($comment,$size='90'); ?>
		</div>
		<div class="comment-content">
			<a href="#comment-<?php comment_ID(); ?>" itemprop="discussionUrl" class="comment-author"><strong class="comment-author-name" itemprop="creator"><?php echo get_comment_author(); ?></strong></a>
			<div class="comment-block-info">
				<div class="comment-time" itemprop="datePublished" content="<?php echo get_the_time('c'); ?>"><?php echo get_comment_date("F d, Y"); ?></div>
				<?php echo get_comment_reply_link(array_merge($args,array(
					'depth' => $depth,
					'reply_text' => esc_html__('Reply', 'love-pet'),
					'max_depth' => $args['max_depth'])));
				?>
			</div>
			<div class="comment-text" itemprop="about">
				<?php if ($comment->comment_approved == '0') : ?>
					<em><?php esc_html_e('Your comment is awaiting moderation.', 'love-pet') ?></em>
				<?php endif; ?>
				<?php comment_text() ?>
			</div>
			<?php edit_comment_link(esc_html__('Edit', 'love-pet'), '  ', '') ?>
		</div>
	</div>
<?php
	break;
	endswitch;
}

/*Author Card*/
if(!function_exists('love_pet_author_card')){
	function love_pet_author_card(){
		if ( empty( $post ) && isset( $GLOBALS['post'] ) )
		$post = $GLOBALS['post'];
		$authordesc = get_the_author_meta( 'description' );
		if(!empty($authordesc)): ?>
			<div class="flw screen-reader-text" itemscope itemtype="https://schema.org/CreativeWork">
				<div class="post-author-info-single" itemprop="author" itemscope itemtype="http://schema.org/Person">
					<div class="author-av"><?php echo get_avatar( $post->ID, $size = 123 ); ?></div>
					<div class="post-author-detail">
						<strong class="author-name" itemprop="name"><?php the_author(); ?></strong>
						<p class="author-desc" itemprop="description"><?php the_author_meta('description'); ?></p>
					</div>
				</div>
			</div><?php
		endif;
	}
}

/*remove query strings*/
function love_pet_remove_script_version( $src ){
	$parts = explode( '?ver', $src );
	return $parts[0];
}
add_filter( 'script_loader_src', 'love_pet_remove_script_version', 15, 1 );
add_filter( 'style_loader_src', 'love_pet_remove_script_version', 15, 1 );

/*defer js file*/
if (!current_user_can('administrator')) {
	function love_pet_defer_parsing_of_js ( $url ) {
		if ( FALSE === strpos( $url, '.js' ) ) return $url;
        if ( strpos( $url, 'jquery.js' ) ) return $url;
		return "$url' defer='defer";
	}
	add_filter( 'clean_url', 'love_pet_defer_parsing_of_js', 11, 1 );
}

/*disable font awesome unyson - front-end*/
function love_pet_dequeue_fontawesome_css() {
	wp_dequeue_style('fw-font-awesome');
	wp_deregister_style('fw-ext-builder-frontend-grid');
	wp_dequeue_style('fw-ext-forms-default-styles');
	wp_deregister_style('fw-font-awesome');
}
add_action('wp_enqueue_scripts','love_pet_dequeue_fontawesome_css', 100);



/*heard of WordPress*/
if ( ! isset( $content_width ) ) $content_width = 1170;


/*remove css of contact form 7*/
add_filter( 'wpcf7_load_css', '__return_false' );

/*custom widget search form*/
add_filter( 'get_search_form', 'love_pet_search_form_widget', 100 );
function love_pet_search_form_widget( $form ) {
    $form =
    '<form role="search" method="get" class="search-form" action="' . home_url( '/' ) . '" >
	    <label class="screen-reader-text" for="s">' . esc_html__( 'Search for:', 'love-pet' ) . '</label>
	    <input type="text" class="search-field" placeholder="'.esc_attr__('Search Post Here...', 'love-pet').'" value="' . get_search_query() . '" name="s" id="s" />
	    <button type="submit" class="search-submit ion-android-search"></button>
    </form>';
    return $form;
}

/*! MODIFY SEARCH WIDGET
------------------------------------------------->*/
add_filter( 'get_product_search_form' , 'love_pet_product_search_form_widget' );
function love_pet_product_search_form_widget( $form ) {
    $form =
    '<form role="search" method="get" class="search-form" action="' . esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ) . '" >
        <label class="screen-reader-text" for="s">' . esc_html__( 'Search for:', 'love-pet' ) . '</label>
        <input type="text" class="search-field" placeholder="'.esc_attr__('Search Product Here...', 'love-pet').'" value="' . get_search_query() . '" name="s" id="s" />
        <button type="submit" class="search-submit ion-android-search"></button>
    </form>';

    return $form;
}

/*GET POST VIEW ON BLOG POST*/
	function love_pet_getPostViews($postID){
		$count_key = 'post_views_count';
		$count = get_post_meta($postID, $count_key, true);
		if($count==''){
			delete_post_meta($postID, $count_key);
			add_post_meta($postID, $count_key, '0');
			return "0";
		}
		return $count;
	}
	function love_pet_setPostViews($postID) {
		$count_key = 'post_views_count';
		$count = get_post_meta($postID, $count_key, true);
		if($count==''){
			$count = 0;
			delete_post_meta($postID, $count_key);
			add_post_meta($postID, $count_key, '0');
		}else{
			$count++;
			update_post_meta($postID, $count_key, $count);
		}
	}

/*Remove issues with prefetching adding extra views*/
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

/*blog post info*/
if(!function_exists('love_pet_post_info')){
	function love_pet_post_info(){
		if(is_single() || is_sticky()):
			global $post; ?>
			<ul class="blog-post-info">
				<li itemprop="author">
					<span class="fa fa-pencil-square-o"></span>
					<?php the_author_posts_link(); ?>
				</li>
				<li itemprop="datePublished" content="<?php echo get_the_time('c'); ?>">
					<span class="fa fa-calendar"></span>
					<?php echo love_pet_post_date();/*post date*/ ?>
				</li>
				<li>
					<span class="ion-eye"></span>
					<?php  echo love_pet_getPostViews(get_the_ID()); ?>
				</li>
				<li itemprop="commentCount">
					<a href="<?php echo get_comments_link($post->ID); ?>"><span class="ion-chatbubbles"></span> <?php echo get_comments_number(); ?></a>
				</li>
			</ul>
		<?php else:
			echo '<div class="list-post-info">' . love_pet_post_date()/*post date*/ . '</div>';
		endif;
	}
}

/*tetimonials rating*/
function love_pet_testi_rating($rating){
	for($x = 0; $x < $rating; $x++){ ?>
		<span class="fa fa-star"></span>
		<?php
	}
	if($rating != 5){
		for($i = 0; $i < 5-$rating; $i++){ ?>
			<span class="fa fa-star-o"></span>
			<?php
		}
	}
}

/*Contact form 7: Disable the configuration validator*/
add_filter( 'wpcf7_validate_configuration', '__return_false' );


/* THEME CONFIG *******************************************************************/

/* header layout */
if(!function_exists('love_pet_header_layout')){
	function love_pet_header_layout(){
		/*PAGE OPTIONS*/
		$pid = get_queried_object_id();
		$p_header_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : '';
		
		/*CUSTOMIZER*/
		$c_header_layout = get_theme_mod('header_layout_cfg', 'layout-6');

		if(isset($p_header_layout['gadget']) && $p_header_layout['gadget'] != 'default' ){
			switch($p_header_layout['gadget']){
				case 'layout-1' :
					get_template_part('page-templates/header', 'layout-1');
					break;
				case 'layout-2' :
					get_template_part('page-templates/header', 'layout-2');
					break;
				case 'layout-3' :
					get_template_part('page-templates/header', 'layout-3');
					break;
				case 'layout-4' :
					get_template_part('page-templates/header', 'layout-4');
					break;
				case 'layout-5' :
					get_template_part('page-templates/header', 'layout-5');
					break;
				case 'layout-6' :
					get_template_part('page-templates/header', 'layout-6');
					break;
			}
		}else{
			switch($c_header_layout){
				case 'layout-1' :
					get_template_part('page-templates/header', 'layout-1');
					break;
				case 'layout-2' :
					get_template_part('page-templates/header', 'layout-2');
					break;
				case 'layout-3' :
					get_template_part('page-templates/header', 'layout-3');
					break;
				case 'layout-4' :
					get_template_part('page-templates/header', 'layout-4');
					break;
				case 'layout-5' :
					get_template_part('page-templates/header', 'layout-5');
					break;
				case 'layout-6' :
					get_template_part('page-templates/header', 'layout-6');
					break;
				default :
					get_template_part('page-templates/header', 'layout-6');
					break;
			}
		}
	}
}

/*header search form*/
if(!function_exists('love_pet_search_form')){
	function love_pet_search_form(){ ?>
		<form class="ht-search-form" action="<?php echo esc_url(home_url('/')); ?>" method="get">
			<span class="ion-ios-close" id="ht-search-close-btn"></span>
			<input id="ht-search-field" type="text" placeholder="<?php esc_attr_e( 'Type to search...', 'love-pet' ); ?>" name="s">
			<i><?php esc_html_e('Hit enter to search', 'love-pet'); ?></i>
		</form>
	<?php }
}

/*header search form*/
if(!function_exists('love_pet_advanced_search_form')){
	function love_pet_advanced_search_form(){
		$categories = get_terms( 'product_cat' ); ?>
		<form class="theme-advanced-search" role="search" method="get" action="<?php echo get_permalink( wc_get_page_id( 'shop' ) ); ?>">
			<input type="hidden" name="product" />
			<?php if(!empty($categories)): ?>
				<label class="search-adv-label">
					<select name="category">
						<option value="product_cat"><?php esc_html_e('All Category', 'love-pet'); ?></option>
						<?php foreach($categories as $key): ?>
						<option value="<?php echo esc_attr($key->slug); ?>"><?php echo esc_html($key->name); ?></option>
						<?php endforeach; ?>
					</select>
				</label>
			<?php endif; ?>
			<span class="search-separator"></span>
			<input name="s" type="text" placeholder="<?php esc_attr_e('Search...', 'love-pet'); ?>" value="<?php echo get_search_query(); ?>" />
			<button type="submit" class="ion-ios-search-strong"></button>
		</form>
	<?php }
}

/*logo*/
if(!function_exists('love_pet_logo_image')){
	function love_pet_logo_image(){
		$pid = get_queried_object_id();
		$p_lg = function_exists('fw_get_db_post_option') ? fw_get_db_post_option($pid, 'p_lg') : '';
		
		$c_lg = get_theme_mod('logo_img', '');
		$lg_img = '';

		$tag = 'figure';
		$tag_child = 'figcaption';
		if( is_front_page() ){
			$tag = 'h1';
			$tag_child = 'span';
		}
		
		
		if(isset($p_lg['gadget']) && $p_lg['gadget'] == 'custom'){
			$lg_img = $p_lg['custom']['lg_data']['url'];
		?>
			<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="ht-logo">
				<a class="lg" href="<?php echo esc_url(home_url('/')); ?>" itemprop="url">
	                <img
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'love-pet'); ?>"
	                	itemprop="logo"
	                	width="123"
	                	height="64" >
	            </a>
	            <<?php echo esc_attr($tag_child); ?> class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></<?php echo esc_attr($tag_child); ?>>
            </<?php echo esc_attr($tag); ?>>
        <?php
			}else{
				$lg_img = ($c_lg != '') ? $c_lg : get_template_directory_uri().'/images/lg.png';
		?>
			<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="ht-logo">
				<a class="lg" href="<?php echo esc_url(home_url("/")); ?>" itemprop="url">
	                <img
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'love-pet'); ?>"
	                	itemprop="logo"
	                	width="123"
	                	height="64" >
	            </a>
	            <<?php echo esc_attr($tag_child); ?> class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></<?php echo esc_attr($tag_child); ?>>
			</<?php echo esc_attr($tag); ?>>
		<?php
		}
	}
}

/*theme styles inline***************************************************************/
function love_pet_styles_inline() {
	$custom_css = '';
	$pid = get_queried_object_id();

	/*menu styles inline=========================*/
		/*get primary menu id*/
		$primary_menu = get_nav_menu_locations();

		if(isset($primary_menu['primary'])){
			/*get list menu item id*/
			$menu = wp_get_nav_menu_items($primary_menu['primary']);
			/*get option of menu item*/
			if(!empty($menu)):
				foreach($menu as $key){
					$options = function_exists('fw_ext_mega_menu_get_db_item_option') ? (fw_ext_mega_menu_get_db_item_option($key->ID, 'row')) : '';
					if(isset($options['bg']) && !empty($options['bg'])){
						$custom_css .= '.menu-item-'.$key->ID.' .mega-menu .mega-menu-row{background-image: url(' . $options['bg']['url'] . ');}';
					}
				}
			endif;
		}

	/*header styles inline=========================*/
		/*header layout 4===*/
		$p_header_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : '';
		if(isset($p_header_layout['gadget']) && $p_header_layout['gadget'] == 'layout-4'){
			/*menu background color*/
			$custom_css .= '.page-id-' . $pid . ' .header-layout-4 .theme-header-row-bot{background-color: ' . $p_header_layout['layout-4']['l4_bg_menu'] . '}';
			/*menu highlight color*/
			$custom_css .=
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li:not(.menu-item-has-mega-menu):hover > a,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li:not(.menu-item-has-mega-menu):hover > a,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li.current-menu-item > a,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li.current-menu-ancestor > a,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li.current-menu-parent > a,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li.current_page_parent > a,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li.current_page_ancestor > a,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li > a:hover,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu > li:not(.menu-item-has-mega-menu) ul a:hover,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu .mega-menu-row > li > a:hover,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu li.menu-item-has-mega-menu:hover > a,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-primary-menu .mega-menu-row .sub-menu a:hover,' .
				'.page-id-' . $pid . ' .header-layout-4 #ht-search-btn:hover, .header-layout-4 .shopping-cart-icon:hover,' .
				'.page-id-' . $pid . ' .header-layout-4 .theme-shopping-cart:hover .shopping-cart-icon' .
				'{color: ' . $p_header_layout['layout-4']['l4_highlight_menu'] . '}';
		}
	/*footer styles inline=========================*/
	
		/*page option: footer*/		
		$p_footer_display = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'p_footer_display') : 'default';
		
		if(isset($p_footer_display['gadget']) && $p_footer_display['gadget'] == 'custom'){
			/*footer background color; remove background image*/
			$custom_css .= '.page-id-' . $pid . ' .theme-footer{background-image: none; background-color: ' . $p_footer_display['custom']['f_bg_color'] . '}';
			/*widget title color*/
			$custom_css .= '.page-id-' . $pid . ' .theme-footer-widget .widget .footer-widget-title{color: ' . $p_footer_display['custom']['f_title_color'] . '}';
			/*widget text content color*/
			$custom_css .= '.page-id-' . $pid . ' .theme-footer-widget .widget *:not(#mc-embedded-subscribe):not(.footer-widget-title){color: ' . $p_footer_display['custom']['f_text_color'] . '}';
			/*infomation background color*/
			$custom_css .= '.page-id-' . $pid . ' .footer-infomation{background-color: ' . $p_footer_display['custom']['f_info_bg_color'] . '}';
			/*infomation text color*/
			$custom_css .= '.page-id-' . $pid . ' .footer-infomation *{color: ' . $p_footer_display['custom']['f_info_text_color'] . '}';
			/*infomation border color*/
			$custom_css .= '.page-id-' . $pid . ' .footer-infomation{border-top-color: ' . $p_footer_display['custom']['f_info_border_color'] . '}';
		}
	wp_add_inline_style( "kirki-styles-love-pet", $custom_css );
}
add_action( 'wp_enqueue_scripts', 'love_pet_styles_inline', 1001);


/*footer widget*/
if(!function_exists('love_pet_footer_widget')){
	function love_pet_footer_widget(){
		if(is_active_sidebar('footer-widget')): ?>
			<div class="theme-footer-widget flw">
				<div class="container">
					<div class="row">
						<?php dynamic_sidebar('footer-widget'); ?>
					</div>
				</div>
			</div>
		<?php endif;
	}
}

/*Extend Visual compoer***************************************************************/
if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {
	function love_pet_require_VC() {
		require_once get_template_directory() . '/inc/vc-include.php';
	}
	add_action( 'init', 'love_pet_require_VC', 2 );
}

/* Edit location *******************************************************************/
/*hader layout edit*/
if(!function_exists('love_pet_header_edit_location')){
	function love_pet_header_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()):
			echo '<div id="'. esc_attr($id) .'-edit-location" class="header-edit-location">';
				if ( class_exists( 'Kirki' ) ){
					echo Kirki::get_option($option);
				}
			echo '</div>';
		endif;
	}
}

/*breadcrumbs layout edit location*/
if(!function_exists('love_pet_bread_edit_location')){
	function love_pet_bread_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()):
			echo '<div id="' . esc_attr($id) . '-edit-location">';
				if ( class_exists( 'Kirki' ) ){
					echo Kirki::get_option($option);
				}
			echo '</div>';
		endif;
	}
}

/*footer layout edit location*/
if(!function_exists('love_pet_footer_edit_location')){
	function love_pet_footer_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()): ?>
			<div id="<?php echo esc_attr($id); ?>-edit-location">
				<?php
					if ( class_exists( 'Kirki' ) ){
						echo Kirki::get_option($option);
					}
				?>
			</div>
		<?php endif;
	}
}



/* WOOCOMMERCE *******************************************************************/

if( class_exists( 'woocommerce' ) ) {
	function love_pet_shop_bread() {
		$_cart = $_checkout = $_end = '';

		/*is cart*/
		if( is_cart() ){
			$_cart = 'active';
		}

		/*is checkout*/
		if( is_checkout() ){
			$_checkout = 'active';
		}

		/*detect thank you page*/
		global $wp;
		if( is_checkout() && ! empty( $wp->query_vars['order-received'] ) ) {
            $_checkout = '';
            $_end      = 'active';
		}
        ?>

		<div class="shop-br">
			<div class="shop-br-item br-cart <?php echo esc_attr( $_cart ); ?>">
				<span><?php esc_html_e( 'Shopping Cart', 'love-pet' ); ?></span>
                
                <?php if( '' == $_cart ){ ?>
                    <a href="<?php echo get_permalink( wc_get_page_id( 'cart' ) ); ?>" class="shop-br-url"></a>
                <?php } ?>
			</div>

			<div class="shop-br-item br-checkout <?php echo esc_attr( $_checkout ); ?>">
				<span><?php esc_html_e( 'Check Out', 'love-pet' ); ?></span>

                <?php if( '' == $_checkout ){ ?>
                    <a href="<?php echo get_permalink( wc_get_page_id( 'checkout' ) ); ?>" class="shop-br-url"></a>
                <?php } ?>
			</div>

			<div class="shop-br-item br-order <?php echo esc_attr( $_end ); ?>">
				<span><?php esc_html_e( 'Order Complete', 'love-pet' ); ?></span>
			</div>
		</div>
	<?php }
}

/*disable css yith woocommerce*/
function love_pet_dequeue_yith_css() {
	wp_dequeue_style('yith-wcwl-main');
	wp_dequeue_style('yith-wcwl-font-awesome');
}
add_action('wp_enqueue_scripts','love_pet_dequeue_yith_css', 100);

/*check yith woocommerce active or deactive*/
if(class_exists('YITH_WCWL')){
	function love_pet_check_yith_enable_or_disable(){
		echo do_shortcode( "[yith_wcwl_add_to_wishlist]" );
	}
	add_action( 'woocommerce_after_shop_loop_item', 'love_pet_check_yith_enable_or_disable', 10 );
}

/*remove css default woocommerce*/
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/*PRODUCT PER PAGE SHOW*/
	function love_pet_jc_get_products_per_page(){ 
		global $woocommerce; 
		$default = 12;
		$count = $default;
		$options = love_pet_jc_get_products_per_page_options(); 
		/*capture form data and store in session*/
		if(isset($_POST['jc-woocommerce-products-per-page'])){ 
			/*set products per page from dropdown*/
			$products_max = intval($_POST['jc-woocommerce-products-per-page']);
			if($products_max != 0 && $products_max >= -1){ 
				if(is_user_logged_in()){ 
					$user_id = get_current_user_id();
					$limit = get_user_meta( $user_id, '_product_per_page', true ); 
					if(!$limit){
						add_user_meta( $user_id, '_product_per_page', $products_max);
					}else{
						update_user_meta( $user_id, '_product_per_page', $products_max, $limit);
					}
				} 
				$woocommerce->session->jc_product_per_page = $products_max;
				return $products_max;
			}
		} 
		/*load product limit from user meta*/
		if(is_user_logged_in() && !isset($woocommerce->session->jc_product_per_page)){ 
			$user_id = get_current_user_id();
			$limit = get_user_meta( $user_id, '_product_per_page', true ); 
			if(array_key_exists($limit, $options)){
				$woocommerce->session->jc_product_per_page = $limit;
				return $limit;
			}
		} 
		/*load product limit from session*/
		if(isset($woocommerce->session->jc_product_per_page)){ 
			// set products per page from woo session
			$products_max = intval($woocommerce->session->jc_product_per_page);
			if($products_max != 0 && $products_max >= -1){
				return $products_max;
			}
		} 
		return $count;
	}
	add_filter('loop_shop_per_page','love_pet_jc_get_products_per_page');

	/*Fetch list of avaliable options*/
	function love_pet_jc_get_products_per_page_options(){
		$options = apply_filters( 'jc_products_per_page', array(
			6 => esc_html__('6', 'love-pet'),
			12 => esc_html__('12', 'love-pet'),
			18 => esc_html__('18', 'love-pet'),
			24 => esc_html__('24', 'love-pet')
		)); 
		return $options;
	} 
	/*Display dropdown form to change amount of products displayed*/
	function love_pet_jc_woocommerce_products_per_page(){ 
		$options = love_pet_jc_get_products_per_page_options(); 
		$current_value = love_pet_jc_get_products_per_page(); ?>
		<div class="pro-per-page">
			<span><?php esc_html_e('View:', 'love-pet'); ?></span>
			<form action="" method="POST" class="woocommerce-products-per-page">
				<select name="jc-woocommerce-products-per-page" onchange="this.form.submit()">
				<?php foreach($options as $value => $name): ?>
					<option value="<?php echo esc_attr($value); ?>" <?php selected($value, $current_value); ?>><?php echo esc_html($name); ?></option>
				<?php endforeach; ?>
				</select>
			</form>
			<span><?php esc_html_e('per page', 'love-pet'); ?></span>
		</div>
	<?php } 
	add_action('woocommerce_before_shop_loop', 'love_pet_jc_woocommerce_products_per_page', 25);
/*END PRODUCT PER PAGE SHOW*/